=====
Usage
=====

The tool cellmaps_vnn allows to build Visible Neural Network (VNN) using hierarchy in CX2 format,
train the network with provided training data and perform predictions, then annotate the hierarchy with the system
importance score, indicating which nodes of the hierarchy (gene sets) were important for making the prediction.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   usage_programmatically
   usage_command_line
   usage_via_docker
   example_usage_nest_vnn


